document.addEventListener('DOMContentLoaded', () => {
  const commandInput = document.getElementById('command-input');
  const terminalOutput = document.getElementById('terminal-output');
  
  const commands = {
    help: 'Available commands: help, clear, date, echo, whoami',
    clear: () => terminalOutput.innerHTML = '',
    date: () => new Date().toLocaleString(),
    echo: (args) => args.join(' '),
    whoami: 'guest@cmd.scroll.pub'
  };

  commandInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
      const input = commandInput.value.trim();
      const [cmd, ...args] = input.split(' ');
      
      addToTerminal(`$ ${input}`);
      
      if (commands.hasOwnProperty(cmd)) {
        const output = typeof commands[cmd] === 'function' 
          ? commands[cmd](args)
          : commands[cmd];
        addToTerminal(output);
      } else {
        addToTerminal(`Command not found: ${cmd}`);
      }
      
      commandInput.value = '';
    }
  });

  function addToTerminal(text) {
    const line = document.createElement('div');
    line.textContent = text;
    terminalOutput.appendChild(line);
    terminalOutput.scrollTop = terminalOutput.scrollHeight;
  }

  // Typing effect for welcome message
  const welcomeText = "Welcome to CMD. Type 'help' to begin.";
  let i = 0;
  function typeWriter() {
    if (i < welcomeText.length) {
      terminalOutput.textContent += welcomeText.charAt(i);
      i++;
      setTimeout(typeWriter, 50);
    }
  }
  typeWriter();
});
